#
# spec file for package python-sfs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-sfs
Version:        0.6.2
Release:        3.5
Summary:        Sound Field Synthesis toolbox for Python
License:        MIT
URL:            https://github.com/sfstoolbox/
Source:         https://files.pythonhosted.org/packages/source/s/sfs/sfs-%{version}.tar.gz
#PATCH-FIX-UPSTREAM https://github.com/sfstoolbox/sfs-python/pull/163 Replace inner1d bei einsum
Patch:          numpy125.patch
# PATCH-FIX-UPSTREAM https://github.com/sfstoolbox/sfs-python/pull/179 Update to changes in matplotlib 3.9.0
Patch:          mpl39.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires:       python-scipy
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
# /SECTION
%python_subpackages

%description
The Sound Field Synthesis Toolbox for Python gives you the
possibility to create numercial simulations of sound field
synthesis methods like wave field synthesis (WFS) or
near-field compensated higher order Ambisonics (NFC-HOA).

%prep
%autosetup -p1 -n sfs-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc NEWS.rst README.rst
%license LICENSE
%{python_sitelib}/sfs
%{python_sitelib}/sfs-%{version}*-info

%changelog
* Mon Sep 16 2024 Markéta Machová <mmachova@suse.com>
- Add patch mpl39.patch to fix build with the new matplotlib
* Thu Sep  7 2023 Markéta Machová <mmachova@suse.com>
- Add upstream patch numpy125.patch
  * replace dropped numpy.core.umath_tests.inner1d by numpy.einsum
* Wed May 31 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.2:
  * build doc fix, use sphinx4, mathjax2, html_css_files
  * New default driving function for `sfs.td.wfs.point_25d()` for
    reference curve
  * New function `sfs.fd.source.line_bandlimited()` computing the
    sound field of a spatially bandlimited line source
  * Drop support for Python 3.5
* Fri Feb 12 2021 Dirk Müller <dmueller@suse.com>
- skip python 36
* Tue Dec  3 2019 Todd R <toddrme2178@gmail.com>
- initial version
